@@ -1,4 +1,7 @@
 """Molecule Application Module."""
+
+from __future__ import annotations
+
 from ansible_compat.runtime import Runtime
 
 
@@ -7,7 +10,7 @@ class App:
 
     def __init__(self) -> None:
         """Create a new app instance."""
-        self.runtime = Runtime(isolated=True)
+        self.runtime = Runtime(isolated=False)
 
 
 app = App()
