@@ -18,22 +18,30 @@
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 #  DEALINGS IN THE SOFTWARE.
 """Prepare Command Module."""
+from __future__ import annotations
 
 import logging
 
+from typing import TYPE_CHECKING
+
 import click
 
 from molecule.api import drivers
 from molecule.command import base
 from molecule.config import DEFAULT_DRIVER
 
+
+if TYPE_CHECKING:
+    from molecule.types import CommandArgs, MoleculeArgs
+
+
 LOG = logging.getLogger(__name__)
 
 
 class Prepare(base.Base):
-    """
-    This action is for the purpose of preparing a molecule managed instance \
-    before the :py:class:`molecule.command.converge.Converge` action is run.
+    """This action is for the purpose of preparing a molecule managed instance.
+
+    Done before the :py:class:`molecule.command.converge.Converge` action is run.
 
     Tasks contained within the ``prepare.yml`` playbook in the scenario
     directory will be run remotely on the managed instance. This action is run
@@ -83,25 +91,25 @@ class Prepare(base.Base):
         molecule.yml.
     """
 
-    def execute(self, action_args=None):
-        """
-        Execute the actions necessary to prepare the instances and returns \
-        None.
+    def execute(self, action_args: list[str] | None = None) -> None:  # noqa: ARG002
+        """Execute the actions necessary to prepare the instances.
 
-        :return: None
+        Args:
+            action_args: Arguments for this command. Unused.
         """
         if self._config.state.prepared and not self._config.command_args.get("force"):
             msg = "Skipping, instances already prepared."
             LOG.warning(msg)
             return
 
-        if not self._config.provisioner.playbooks.prepare:
-            msg = "Skipping, prepare playbook not configured."
-            LOG.warning(msg)
-            return
+        if self._config.provisioner:
+            if not self._config.provisioner.playbooks.prepare:
+                msg = "Skipping, prepare playbook not configured."
+                LOG.warning(msg)
+                return
 
-        self._config.provisioner.prepare()
-        self._config.state.change_state("prepared", True)
+            self._config.provisioner.prepare()
+            self._config.state.change_state("prepared", value=True)
 
 
 @base.click_command_ex()
@@ -124,11 +132,23 @@ class Prepare(base.Base):
     default=False,
     help="Enable or disable force mode. Default is disabled.",
 )
-def prepare(ctx, scenario_name, driver_name, force):  # pragma: no cover
-    """Use the provisioner to prepare the instances into a particular starting state."""
-    args = ctx.obj.get("args")
-    subcommand = base._get_subcommand(__name__)
-    command_args = {
+def prepare(
+    ctx: click.Context,
+    scenario_name: str,
+    driver_name: str,
+    force: bool,  # noqa: FBT001
+) -> None:  # pragma: no cover
+    """Use the provisioner to prepare the instances into a particular starting state.
+
+    Args:
+        ctx: Click context object holding commandline arguments.
+        scenario_name: Name of the scenario to target.
+        driver_name: Name of the Molecule driver to use.
+        force: Whether to use force mode.
+    """
+    args: MoleculeArgs = ctx.obj.get("args")
+    subcommand = base._get_subcommand(__name__)  # noqa: SLF001
+    command_args: CommandArgs = {
         "subcommand": subcommand,
         "driver_name": driver_name,
         "force": force,
